<?php

////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Add options needed for plugin
add_option('fu_fastpostlists_style', '.post_index_group_head {
  font-weight: bold;
}
.post_index_table { 
  display: table; 
  border-spacing: 0.4em;
}
.post_index_row { 
  display: table-row; 
}
.post_index_cell { 
  display: table-cell; 
  vertical-align: top;
  padding: 0.3em;
}
.post_index_cellimg { 
  display: table-cell;
  vertical-align: middle;
  width: 48px;
  margin: 0.3em;
}');
add_option('fu_fastpostlists_headhtml', '');
add_option('fu_fastpostlists_posthtml', '<div class="post_index_table"><div class="post_index_row">
<div class="post_index_cellimg"><a href="[permalink]">[img]</a></div>
<div class="post_index_cell"><a href="[permalink]">[title]</a></div>
</div></div>');
add_option('fu_fastpostlists_foothtml', '');

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Admin page user interface

add_action('admin_menu', 'fubaby_fastpostlists_menu');

function fubaby_fastpostlists_menu() {
	add_options_page(__('Fast Post Lists Options', 'fast-post-lists'), 'Fast Post Lists', 'manage_options', 'fubaby_fastpostlists_options_general', 'fubaby_fastpostlists_options_general');
	add_action( 'admin_init', 'fubaby_fastpostlists_register_settings' );
}

///////////////////////////////////////////////////////////////////////////////////////
// Begin general options

function fubaby_fastpostlists_register_settings()
{
  // First, we register a section. This is necessary since all future options must belong to one.
  add_settings_section(
      'fubaby_fastpostlists_settings_section',         // ID used to identify this section and with which to register options
      __('General Options', 'fast-post-lists'),                  // Title to be displayed on the administration page
      'fubaby_fastpostlists_options_callback', // Callback used to render the description of the section
      'fubaby_fastpostlists_options_general'   // Page on which to add this section of options
      );

  add_settings_field(
      'fu_fastpostlists_style',          // ID used to identify the field throughout the theme
      __('CSS Style (inserted into header)', 'fast-post-lists'),   // The label to the left of the option interface element
      'fubaby_fastpostlists_textarea_callback',   // The name of the function responsible for rendering the option interface
      'fubaby_fastpostlists_options_general',     // The page on which this option will be displayed
      'fubaby_fastpostlists_settings_section',    // The name of the section to which this field belongs
      array(                              // The array of arguments to pass to the callback. In this case, just a description.
          'fu_fastpostlists_style',
          __('CSS Style', 'fast-post-lists'),
          8
      )
    );
  add_settings_field(
      'fu_fastpostlists_headhtml',
      __('HTML header to post index:', 'fast-post-lists'),
      'fubaby_fastpostlists_textarea_callback',
      'fubaby_fastpostlists_options_general',
      'fubaby_fastpostlists_settings_section',
      array(
          'fu_fastpostlists_headhtml',
          __('HTML header', 'fast-post-lists'),
          4
      )
    );
  add_settings_field(
      'fu_fastpostlists_posthtml',
      __('HTML for each post', 'fast-post-lists'),
      'fubaby_fastpostlists_textarea_callback',
      'fubaby_fastpostlists_options_general',
      'fubaby_fastpostlists_settings_section',
      array(
          'fu_fastpostlists_posthtml',
          __('HTML per post', 'fast-post-lists'),
          6,
          sprintf(
            /* translators: %1, %2, %3: keywords */
            __('Keys to be replaced:<br/>%1$s - post title<br>%2$s - post permalink<br>%3$s - first attached post image<br>%4$s - post date<br>', 'fast-post-lists'),
          '[title]', '[permalink]', '[img]', '[date]') 
      )
    );  
   add_settings_field(
      'fu_fastpostlists_foothtml',
      __('HTML footer to post index:', 'fast-post-lists'),
      'fubaby_fastpostlists_textarea_callback',
      'fubaby_fastpostlists_options_general',
      'fubaby_fastpostlists_settings_section',
      array(
          'fu_fastpostlists_foothtml',
          __('HTML footer', 'fast-post-lists'),
          4
      )
    );

  // register our settings
  register_setting( 'fu_fastpostlists_settings_group', 'fu_fastpostlists_style' );
  register_setting( 'fu_fastpostlists_settings_group', 'fu_fastpostlists_headhtml' );
  register_setting( 'fu_fastpostlists_settings_group', 'fu_fastpostlists_posthtml' );
  register_setting( 'fu_fastpostlists_settings_group', 'fu_fastpostlists_foothtml' );

}

function fubaby_fastpostlists_options_callback()
{
}

function fubaby_fastpostlists_options_general()
{
  if (!current_user_can('manage_options'))  {
    wp_die( __('You do not have sufficient permissions to access this page.', "fast-post-lists") );
  }  
  
  ?>
<div class="wrap">
<h2>Fubaby Fast Post Lists</h2>
<p><a href="https://www.fubaby.com/wordpress-plugins/fast-post-lists/" target="_blank"><?php _e("Further documentation and info can be found here", "fast-post-lists"); ?></a></p>

  <!-- Create the form that will be used to render our options -->  
  <form method="post" action="options.php">  
    <?php 
    settings_fields( 'fu_fastpostlists_settings_group' ); 
    ?>  
    <?php do_settings_sections( 'fubaby_fastpostlists_options_general' ); ?>             
    <?php submit_button(); ?>  
  </form>  
  
</div>
<?php
}


function fubaby_fastpostlists_textarea_callback($args) 
{    
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field  
  $html = '<textarea cols="80" rows="'.(isset($args[2]) ? $args[2] : 4).'" id="'.$args[0].'" name="'.$args[0].'">'.get_option($args[0]).'</textarea>';
  if (isset($args[3])) $html .= '<p>' . $args[3] . '</p>';
  echo $html;  
}

?>