<?php
/*
Plugin Name: Fast Post Lists
Plugin URI: http://www.fubaby.com/wordpress-plugins/fast-post-lists/
Description: Creates a lists of posts, for use as an index or contents pages, based upon given search criteria.
Version: 0.7.1
Author: Arthur Yarwood
Author URI: http://www.fubaby.com
Author URI:  https://developer.wordpress.org/
Text Domain: fast-post-lists
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

/*

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

require __DIR__."/admin.php";


// Shortcode handler to create the post index
function fubaby_fastpostlists_shortcode($attrs, $content, $name)
{	
	$results = "";
	
	extract(shortcode_atts(array(
					'search' => '',
					'cat' => '',
					'notcat' => '',
					'tag' => '',
					'nottag' => '',
					'maxposts' => -1,
					'groupby' => '',
					'orderby' => 'title'
					), $attrs));					
					
	// Setup query args
	$args = array();
	if ($search != '') $args['s'] = $search;
	if ($cat != ''){ if (is_numeric($cat)) $args['cat'] = $cat; else $args['category_name'] = $cat; }
	if ($notcat != '') $args['category__not_in'] = $notcat;
	if ($tag != '') $args['tag'] = $tag;
	if ($nottag != '') $args['tag__not_in'] = $nottag;
	$args['posts_per_page'] = $maxposts;
	
	$args['order'] = 'ASC';
	$args['orderby'] = $orderby;

	$cacheHash = "fu_fastpostlists_" . implode(',', $args);
	$results = wp_cache_get($cacheHash);
	if (false !== $results)	
	  return $results;
  	
	// No cache, so query (without global var) 
	$query = new WP_Query( $args );
	$posts = array();

	// The Loop
	while( $query->have_posts() ) {
		$query->next_post();
		$query->post->cat_ids = wp_get_post_categories($query->post->ID);
		$query->post->tag_ids = wp_get_post_tags($query->post->ID, array( 'fields' => 'ids' ) );
		$posts[] = $query->post;
	}

	// Restore original Post Data
	wp_reset_postdata();
  	
	// Dump results
	if ($groupby == 'cat') {
		// get all categories and group posts by them.
		$categories = get_terms( 'category', 'orderby=name&hide_empty=0' );
		foreach ($categories as $cat) {			
			// Find posts in this cat.
			$groupPosts = array();
			foreach ($posts as $post) {
				if ( in_array($cat->term_id, $post->cat_ids) ) {
					$groupPosts[] = $post;
				}
			}
			
			if (count($groupPosts) > 0) {
				$results .= '<div class="post_index_group_head">' . $cat->name . '</div>';
				$results .= fubaby_fastpostlists_writeposts($groupPosts);
			}
		}
	}
	else if ($groupby == 'tag') {
		// get all categories and group posts by them.
		$tags = get_terms( 'post_tag', 'orderby=name&hide_empty=0' );
		foreach ($tags as $tag) {
			
			// Find posts in this cat.
			$groupPosts = array();
			foreach ($posts as $post) {
				if ( in_array($tag->term_id, $post->tag_ids) ) {
					$groupPosts[] = $post;
				}
			}
			
			// Write out this group.
			if (count($groupPosts) > 0) {
				$results .= '<div class="post_index_group_head">' . $tag->name . '</div>';
				$results .= fubaby_fastpostlists_writeposts($groupPosts);
			}
		}
	}
	else {
		$results .= fubaby_fastpostlists_writeposts($posts);
	}
	
	// Cache results for next time.
	wp_cache_set($cacheHash, $results);
  return $results;
}


add_shortcode('fu_postlist', 'fubaby_fastpostlists_shortcode');

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Add shortcode buttons to quick tag bar.
/*
function fu_fastpostlists_addquicktags() {
  if (wp_script_is('quicktags')){
    echo "<script type=\"text/javascript\">\n";
    echo "QTags.addButton( 'fu_postlist', '" . __("Post List", "fast-post-lists") . "', '[fu_postlist]', '', '', '" . __("Fast Post List shortcode", "fast-post_lists") . "', 201 );";
    echo "</script>\n";
    }
}
add_action( 'admin_print_footer_scripts', 'fu_fastpostlists_addquicktags' );
*/

function fu_fastpostlists_enqueue_script()
{
  wp_enqueue_script( 'fastpostlists-admin-js', plugin_dir_url( __FILE__ ) . 'admin.js', array( 'jquery', 'quicktags' ), '1.0.0', true );
}
add_action( 'admin_enqueue_scripts', 'fu_fastpostlists_enqueue_script' );



function fubaby_fastpostlists_headerstyle() {
	echo '<style type="text/css">';
	echo get_option('fu_fastpostlists_style');
	echo '</style>';
}

add_action('wp_head', 'fubaby_fastpostlists_headerstyle');



// Function to write out an array of posts as unordered list.
function fubaby_fastpostlists_writeposts($posts) {
	$postHtmlTemplate = get_option('fu_fastpostlists_posthtml');

	$results = get_option('fu_fastpostlists_headhtml');

	foreach ($posts as $post) {
		$postHtml = $postHtmlTemplate;
		$postHtml = str_replace('[permalink]', get_permalink($post), $postHtml);
		$postHtml = str_replace('[title]', get_the_title($post->ID), $postHtml);
		$postHtml = str_replace('[date]', get_the_date('', $post->ID), $postHtml);
				
		$args = array( 'post_type' => 'attachment', 'numberposts' => 1, 'post_status' =>'any', 'post_parent' => $post->ID ); 
		$attachments = get_posts($args);
		if ($attachments) {
			foreach ( $attachments as $attachment ) {
				$postHtml = str_replace('[img]', wp_get_attachment_image($attachment->ID , array(48,48)), $postHtml);
			}
		}
		else {
			$postHtml = str_replace('[img]', '', $postHtml);
		}				

		$results .= $postHtml;

	}
	
	$results .= get_option('fu_fastpostlists_foothtml');
	
	return $results;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Add settings link on WP plugin page

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'fu_fastpostlists_settings_link');
function fu_fastpostlists_settings_link( $actions ) 
{
  $mylinks = array(
    '<a href="' . admin_url( 'options-general.php?page=fubaby_fastpostlists_options_general' ) . '">' . __('Settings', 'fast-post-lists') . '</a>',
  );
  $actions = array_merge( $actions, $mylinks );
	return $actions;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////
// Remove options on uninstall.

function fubaby_fastpostlists_uninstall()
{
  delete_option("fu_fastpostlists_style");
  delete_option("fu_fastpostlists_headhtml");
  delete_option("fu_fastpostlists_posthtml");
  delete_option("fu_fastpostlists_foothtml");  
}

register_uninstall_hook(__FILE__, 'fubaby_fastpostlists_uninstall');
?>
